@@ -6,6 +6,7 @@ use warnings;
 
 use Data::Printer;
 use Getopt::Long::Descriptive;
+use Pod::Usage;
 use JSON;
 use Parse::Syslog::Line qw( parse_syslog_line );
 use YAML;
@@ -38,21 +39,25 @@ my ($opt,$usage) = describe_options("%c %o",
     }],
     [],
     ['Field Control'],
+    ['sdata|s',  'Enable SDATA detection (JSON and K/V pairs)'],
     ['empty|e',  'Display fields with undef or blank string', ],
     ['raw|r',    'Display the raw fields in the hash.',],
     ['all|a', 'Display all fields.', { implies => [qw(raw empty)] }],
     [],
-    ['help', 'Display this help', { shortcircuit => 1 }],
+    ['help',   'Display this help', { shortcircuit => 1 }],
+    ['manual', 'Display the manual', { shortcircuit => 1 }],
 );
 if( $opt->help ) {
     print $usage->text;
     exit 0;
 }
+pod2usage(-verbose => 2, -exitval => 0 ) if $opt->manual;
 
 
 # Configure
 $Parse::Syslog::Line::PruneEmpty = !$opt->empty;
 $Parse::Syslog::Line::PruneRaw   = !$opt->raw;
+$Parse::Syslog::Line::AutoDetectJSON = $Parse::Syslog::Line::AutoDetectKeyValues = $opt->sdata;
 
 while(<>) {
     my $msg = parse_syslog_line($_);
@@ -71,7 +76,7 @@ parse-syslog-line.pl - Parse a syslog message and display the structured data
 
 =head1 VERSION
 
-version 4.2
+version 4.3
 
 =head1 SYNOPSIS
 
@@ -87,7 +92,11 @@ For help, see:
 
 Use C<parse-syslog-line.pl> as a way to do things with L<jq|https://stedolan.github.io/jq/>:
 
-    tail /var/log/messages | parse-syslog-line.pl --json |jq '.program'
+    tail /var/log/messages | parse-syslog-line.pl --json |jq '.program_name'
+
+Attempt to extract all structured data in the log:
+
+    tail /var/log/messages | parse-syslog-line.pl --sdata --json |jq '{ program: .program_name, sdata: .SDATA }'
 
 See all the keys available,
 
